@@ -1,6 +1,6 @@
 /* BEGIN_LEGAL 
 
-Copyright (c) 2023 Intel Corporation
+Copyright (c) 2025 Intel Corporation
 
   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
@@ -16,31 +16,62 @@ Copyright (c) 2023 Intel Corporation
   
 END_LEGAL */
 
+/// @file xed-enc2-1.c
+/// @brief Showcases the use of ENC2 encode APIs
+
 #include "xed/xed-interface.h"
-#include "xed/xed-chk-enc2-m64-a64.h"
+#include "xed/xed-enc2-m64-a64.h"
 #include <stdio.h>
 #include <stdlib.h>
-#include <stdarg.h>
 
+static xed_uint32_t test_add_lock_byte(xed_uint8_t* output_buffer)
+{
+    xed_reg_enum_t reg0;
+    xed_reg_enum_t base;
+    xed_enc2_req_t request;
+    xed_enc2_req_t_init(&request, output_buffer);
+    reg0 = XED_REG_AH;
+    base = XED_REG_RBX;
+    xed_enc_add_lock_m8_r8_b_a64(&request,base,reg0);
+    return xed_enc2_encoded_length(&request);
+}
 static xed_uint32_t test_0_xed_enc_lea_rm_q_bisd32_a64(xed_uint8_t* output_buffer)
 {
-    xed_reg_enum_t dest;
+    xed_enc2_req_t* r;
+    xed_reg_enum_t reg0;
     xed_reg_enum_t base;
     xed_reg_enum_t index;
     xed_uint_t scale;
     xed_int32_t disp32;
     xed_enc2_req_t request;
     xed_enc2_req_t_init(&request, output_buffer);
-    dest = XED_REG_XMM5; // INTENTIONAL ERROR FOR EXAMPLE. THIS SHOULD BE A GPR LIKE R11
+    r = &request;
+    reg0 = XED_REG_R11;
     base = XED_REG_R12;
     index = XED_REG_R13;
     scale = 1;
     disp32 = 0x11223344;
-    xed_enc_lea_r64_m_bisd32_a64_chk(&request /*req*/,dest /*gpr64*/,base /*gpr64*/,index /*gpr64*/,scale /*scale*/,disp32 /*int32*/);
-    return xed_enc2_encoded_length(&request);
+    xed_enc_lea_r64_m_bisd32_a64(r /*req*/,reg0 /*gpr64*/,base /*gpr64*/,index /*gpr64*/,scale /*scale*/,disp32 /*int32*/);
+    return xed_enc2_encoded_length(r);
 }
 
-
+xed_uint32_t test_0_xed_enc_vpblendvb_xxxx(xed_uint8_t* output_buffer)
+{
+    xed_enc2_req_t* r;
+    xed_reg_enum_t reg0;
+    xed_reg_enum_t reg1;
+    xed_reg_enum_t reg2;
+    xed_reg_enum_t reg3;
+    xed_enc2_req_t request;
+    xed_enc2_req_t_init(&request, output_buffer);
+    r = &request;
+    reg0 = XED_REG_XMM6;
+    reg1 = XED_REG_XMM7;
+    reg2 = XED_REG_XMM8;
+    reg3 = XED_REG_XMM9;
+    xed_enc_vpblendvb_x_x_x_x_128(r /*req*/,reg0 /*xmm*/,reg1 /*xmm*/,reg2 /*xmm*/,reg3 /*xmm*/);
+    return xed_enc2_encoded_length(r);
+}
 
 // The decoder drags in a lot of stuff to the final executable.
 #define DECO
@@ -95,29 +126,42 @@ static void dump(xed_uint8_t* buf, xed_uint32_t len) {
         printf("%02x ",buf[i]);
 }
 
-void my_error_handler(const char* fmt, va_list args) {
-    printf("LOCAL HANDLER FOR XED ENC2 ERROR: ");
-    vprintf(fmt, args);
-    printf(".\n");
-    exit(1); 
-}
-
-
 int main(int argc, char** argv) {
     xed_uint8_t output_buffer[XED_MAX_INSTRUCTION_BYTES];
     xed_uint32_t enclen;
-    int retval=0;
-    xed_enc2_set_error_handler(my_error_handler);
-    // uncomment this line to disable runtime checking
-    //xed_enc2_set_check_args(0);
-    
+    int retval=0, r=0;
+
+    // encode an LEA instruction
     enclen = test_0_xed_enc_lea_rm_q_bisd32_a64(output_buffer);
     printf("Encoded: ");
     dump(output_buffer, enclen);
     printf("\n");
 #if defined(DECO)
-    retval =  decode(output_buffer, enclen);
-    printf("decode returned %d\n",retval);
+    r =  decode(output_buffer, enclen);
+    retval += r;
+    printf("decode returned %d\n",r);
+#endif
+    
+    // encode an VPBLENDVB instruction with 4 xmm regs
+    enclen = test_0_xed_enc_vpblendvb_xxxx(output_buffer);
+    printf("Encoded: ");
+    dump(output_buffer, enclen);
+    printf("\n");
+#if defined(DECO)
+    r = decode(output_buffer, enclen);
+    retval += r;
+    printf("decode returned %d\n",r);
+#endif
+
+    
+    enclen = test_add_lock_byte(output_buffer);
+    printf("Encoded: ");
+    dump(output_buffer, enclen);
+    printf("\n");
+#if defined(DECO)
+    r = decode(output_buffer, enclen);
+    retval += r;
+    printf("decode returned %d\n",r);
 #endif
     (void)argc; (void)argv;
     return retval;
