@@ -2,7 +2,7 @@
 # -*- python -*-
 #BEGIN_LEGAL
 #
-#Copyright (c) 2022 Intel Corporation
+#Copyright (c) 2024 Intel Corporation
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -65,7 +65,7 @@ class env_t(object):
              - separate_pdb_files       defaultE{:} False
              - targets     defaultE{:} []  targets to build
              - verbose     defaultE{:} 1
-             - compiler    defaultE{:} 'gnu', 'ms', 'clang', 'icc', 'icl', 'iclang'
+             - compiler    defaultE{:} 'gnu', 'ms', 'clang', 'icc', 'icl', 'iclang', 'icx'
              - extra_defines   defaultE{:} '' 
              - extra_flags     defaultE{:} ''  (for both CXXFLAGS & CCFLAGS)
              - extra_cxxflags  defaultE{:} ''
@@ -94,6 +94,7 @@ class env_t(object):
           - icc_version    7, 8, 9, 10, ...
           - gcc_version    2.96, 3.x.y, 4.x.y, ...
           - msvs_version   6 (VC98), 7 (.NET 2003), 8 (Pro 2005), ...
+          - no_mscrt       No implicit MSVC CRT-library build knob (/MT[d], /MD[d])
           
           - primary compilation toolsE{:}
              - CC             cl or gcc          (with toolchain path)
@@ -296,7 +297,7 @@ class env_t(object):
             t = self._mysub(t,name,v)
             m = subs_pattern.search(t)
             if debug:
-                uprint(t)
+                print(t)
         return t
     
     def _dosub_old(self,s,d):
@@ -451,8 +452,8 @@ class env_t(object):
         distro = ''
         distro_ver = ''
         if  not self.on_mac()  and   not self.on_windows():
-            if util.check_python_version(3,8):
-                # With python 3.8 one needs to install the python "distro"
+            if util.check_python_version(3,9):
+                # With python 3.9 one needs to install the python "distro"
                 # package to obtain the linux distro information. I do not
                 # want to require users to install a non-default package
                 # so we'll have to live without the distro information.
@@ -555,6 +556,7 @@ class env_t(object):
             vc_dir='',
             msvs_version='',
             setup_msvc=False,
+            mbuild_mscrt=True,
             icc_version='',
             gcc_version='',
             cc='',
@@ -628,7 +630,7 @@ class env_t(object):
             "--compiler",
             dest="compiler",
             action="store",
-            help="Compiler (ms,gnu,clang,icc,icl,iclang)." +
+            help="Compiler (ms,gnu,clang,icc,icl,iclang, icx)." +
                  " Default is gnu on linux and" + 
                  " ms on windows. Default is: %s" % (self.default_compiler()))
         self.parser.add_option(
@@ -718,6 +720,12 @@ class env_t(object):
             action='store_true',
             help="Use the value of the --msvc-version to initialize" +
             " the MSVC configuration.")
+        self.parser.add_option(
+            "--no-mscrt",
+            dest="mbuild_mscrt",
+            action="store_false",
+            help="No implicit MSVC CRT-library build knob (/MT[d], /MD[d])"
+            )
         self.parser.add_option(
             '--icc-version',
             '--iccver',
@@ -1275,7 +1283,7 @@ class env_t(object):
 
         @type compiler_family: string
         @param compiler_family: an override for the default 
-                       compiler family (gnu, ms, clang, icl, icc, iclang)
+                       compiler family (gnu, ms, clang, icl, icc, iclang, icx)
         """
 
 
@@ -1312,6 +1320,8 @@ class env_t(object):
             build_env.set_env_iclang(self)
         elif compiler_family == 'icl':
             build_env.set_env_icl(self)
+        elif compiler_family == 'icx':
+            build_env.set_env_icx(self)
         else:
             die("Compiler family not recognized. Need gnu or ms")
 
@@ -2039,7 +2049,7 @@ class env_t(object):
     def _dynamic_lib_default(self, objs, libname, relocate=False):
         """Make a dynamic library libname from objs. If relocate is True,
         then prefix libname with the build directory name"""
-        if self.env['compiler'] in [ 'gnu','icc','clang','iclang']:
+        if self.env['compiler'] in [ 'gnu','icc','clang','iclang','icx']:
             cmd = self.env['CXX_SHARED_LIB_COMMAND']
         else:
             cmd = self.env['DYNAMIC_LIB_COMMAND']
