@@ -33,7 +33,8 @@ END_LEGAL */
 #include "xed3-dynamic-decode.h"
 #include "xed3-dynamic-part1-capture.h"  //FIXME fix filename
 #include "xed-chip-features.h"
-#include "xed-chip-features-private.h" // for xed_test_chip_features()
+#include "xed-chip-features-private.h" // for xed_test_features()
+#include "xed-chip-features-table.h"
 #include "xed-chip-modes.h"
 #include "xed-reg-class.h"
 
@@ -95,7 +96,7 @@ static void check_src2_dest_match(xed_decoded_inst_t* xds) {
 }
 #endif
 
-#if defined(XED_ATTRIBUTE_NO_SRC_DEST_MATCH_DEFINED)
+#if defined(XED_ATTRIBUTE_NO_REG_MATCH_DEFINED)
 /* this is essentially targeted at AMX instructions but applies to others (e.g. POP2{,P})
    The check could be more robust to allow ignoring even more registers or by allowing
    compares exclusively to type-exact registers
@@ -178,6 +179,17 @@ xed_decode_finalize_operand_storage_fields(xed_decoded_inst_t* xds)
             if (xed3_operand_get_mode(xds)==2)  // 64b mode
                 xed3_operand_set_error(xds,XED_ERROR_GENERAL_ERROR);
 #endif
+    if (xed3_operand_get_realmode(xds)!=0) {
+        // Illegal for VEX/EVEX or PROTECTED_MODE instructions
+        if (xed3_operand_get_vexvalid(xds) || 
+            xed_decoded_inst_get_attribute(xds, XED_ATTRIBUTE_PROTECTED_MODE)) {
+            // SEP/SMX legality is also CPL-dependent -> Skip check.
+            if (xed_decoded_inst_get_isa_set(xds) != XED_ISA_SET_SEP &&
+                xed_decoded_inst_get_isa_set(xds) != XED_ISA_SET_SMX) {
+                    xed3_operand_set_error(xds,XED_ERROR_INVALID_MODE);
+            }
+        }
+    }
 }
 
 
@@ -187,13 +199,21 @@ xed_error_enum_t
 xed_decode_with_features(xed_decoded_inst_t* xedd, 
                          const xed_uint8_t* itext, 
                          const unsigned int bytes,
-                         xed_chip_features_t* features)
+                         xed_chip_features_t* chip_features)
 {
     xed_error_enum_t error;
     unsigned int tbytes = bytes;
     xed_chip_enum_t chip = xed_decoded_inst_get_input_chip(xedd);
+    xed_features_elem_t const* features = 0;
+    if (chip_features) {
+        features = chip_features->f;
+    }
+    else if (chip != XED_CHIP_INVALID) {
+        features = xed_get_features(chip);
+    }
 
     set_chip_modes(xedd, chip, features);
+
     xedd->_byte_array._dec = itext;
     
     /* max_bytes says ILD how many bytes it can read */    
@@ -234,24 +254,20 @@ xed_decode_with_features(xed_decoded_inst_t* xedd,
     xed_decode_finalize_operand_storage_fields(xedd);
 
     error = xed3_operand_get_error(xedd);
-    if (error == XED_ERROR_NONE) {
-        if (chip != XED_CHIP_INVALID) {
-            if (!xed_decoded_inst_valid_for_chip(xedd, chip))  {
-                return XED_ERROR_INVALID_FOR_CHIP;
-            }
+    if (error == XED_ERROR_NONE && features)
+    {
+        const xed_isa_set_enum_t isa_set = xed_decoded_inst_get_isa_set(xedd);
+        if (!xed_test_features(features, isa_set))
+        {
+            return XED_ERROR_INVALID_FOR_CHIP;
+        }
 #if defined(XED_APX)
-            // Check APX instructions with no-APX ISA-SET
-            if (!chip_supports_apx(xedd) && xed_classify_apx(xedd)){
-                return XED_ERROR_INVALID_FOR_CHIP;
-            }
+        // Check legacy instructions with APX repurposed prefix bits
+        if (!decoder_supports_apx(xedd) && xed_classify_apx(xedd))
+        {
+            return XED_ERROR_INVALID_FOR_CHIP;
+        }
 #endif
-        }
-        if (features) {
-            const xed_isa_set_enum_t isa_set = xed_decoded_inst_get_isa_set(xedd);
-            if (!xed_test_chip_features(features, isa_set)) {
-                return XED_ERROR_INVALID_FOR_CHIP;
-            }
-        }
     }
     return error;
 }
