@@ -1,6 +1,6 @@
 /* BEGIN_LEGAL 
 
-Copyright (c) 2024 Intel Corporation
+Copyright (c) 2025 Intel Corporation
 
   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
@@ -240,6 +240,26 @@ void xed_format_set_options(xed_format_options_t format_options) {
     xed_format_options = format_options;
 }
 
+static int xml_tag(char* buf, int blen, char const* tag, xed_uint_t value) {
+    char tbuf[XED_HEX_BUFLEN];
+
+    blen = xed_strncat(buf,"<",blen);
+    blen = xed_strncat(buf,tag,blen);
+    blen = xed_strncat(buf," bits=\"",blen); 
+
+    xed_sprintf_uint32(tbuf, value, XED_HEX_BUFLEN);
+    blen = xed_strncat(buf,tbuf,blen); 
+
+    blen = xed_strncat(buf,"\">",blen);
+    return blen;
+}
+
+static void xml_tag_pi(xed_print_info_t* pi,
+                      char const* tag,
+                      xed_uint_t value)
+{
+    pi->blen = xml_tag(pi->buf, pi->blen, tag, value);
+}
 
 static int
 xml_print_flags(const xed_decoded_inst_t* xedd, char* buf, int blen)
@@ -251,6 +271,19 @@ xml_print_flags(const xed_decoded_inst_t* xedd, char* buf, int blen)
         unsigned int nflags = xed_simple_flag_get_nflags(rfi);
         unsigned int i;
         blen = xed_strncat(buf,"<FLAGS>",blen);
+#if defined(XED_APX)
+        if (xed_decoded_inst_has_default_flags_values(xedd)){
+            /* print Default Flags Values */
+            xed_flag_dfv_t dfv_mask;
+            xed_bool_t okay = xed_decoded_inst_get_default_flags_values(xedd, &dfv_mask);
+            if(okay) {
+                blen = xml_tag(buf, blen, "of-default", dfv_mask.s.of);
+                blen = xml_tag(buf, blen, "sf-default", dfv_mask.s.sf);
+                blen = xml_tag(buf, blen, "zf-default", dfv_mask.s.zf);
+                blen = xml_tag(buf, blen, "cf-default", dfv_mask.s.cf);
+            }
+        }
+#endif
         for( i=0;i<nflags ;i++) {
             char tbuf[XED_HEX_BUFLEN];
             const xed_flag_action_t* fa = xed_simple_flag_get_flag_action(rfi,i);
@@ -258,7 +291,6 @@ xml_print_flags(const xed_decoded_inst_t* xedd, char* buf, int blen)
                 blen = xed_strncat(buf, " ",blen);
             (void) xed_flag_action_print(fa,tbuf,XED_HEX_BUFLEN);
             blen = xed_strncat(buf, tbuf,blen);
-
         }
         blen = xed_strncat(buf,"</FLAGS>",blen);
     }
@@ -298,8 +330,27 @@ xml_print_end(xed_print_info_t* pi,
     }
 }
 
+/* Uses the XED autogenerated assembly conversion table, typically for handling operand decorations. */
+static int xed_print_cvt(const xed_decoded_inst_t* p, 
+                         char* buf,
+                         int blen,
+                         xed_operand_convert_enum_t    cvt) {
+    // 32bit var is enough since the only operand wider than 32b disp/imm 
+    // and we are not decorating those
+    xed_uint_t opvalue;
+    xed_operand_enum_t index_operand = xed_convert_table[cvt].opnd;
+    xed3_get_generic_operand(p,index_operand,&opvalue);
+    if (opvalue < xed_convert_table[cvt].limit) {
+        const char* s = xed_convert_table[cvt].table_name[ opvalue ];
+        blen = xed_strncat(buf,s,blen);
+    }
+    else 
+        blen = xed_strncat(buf,"BADCVT",blen);
+    return blen;
+}
+
 static void
-xed_decoded_inst_dump_common(xed_print_info_t* pi)
+xed_decoded_inst_dump_common_pre_mne(xed_print_info_t* pi)
 {
     const xed_operand_values_t* ov = xed_decoded_inst_operands_const(pi->p);  
 
@@ -330,10 +381,10 @@ xed_decoded_inst_dump_common(xed_print_info_t* pi)
         xed_prefixes(pi,"notrack");
     else if (pi->format_options.emit_ignored_branch_taken_hint 
                 && xed_operand_values_ignored_branch_not_taken_hint(ov))
-        xed_prefixes(pi,"hint-not-taken");
+        xed_prefixes(pi,"cs");  // non-JCC instruction with ignored CS prefix
     else if (pi->format_options.emit_ignored_branch_taken_hint
                  && xed_operand_values_ignored_branch_taken_hint(ov))
-        xed_prefixes(pi,"hint-taken");
+        xed_prefixes(pi,"ds");  // non-JCC instruction with ignored DS prefix
 
     if (xed_operand_values_has_address_size_prefix(ov)) {
         if (xed_decoded_inst_explicit_memop(pi->p) == 0) {
@@ -351,6 +402,10 @@ xed_decoded_inst_dump_common(xed_print_info_t* pi)
                 xed_prefixes(pi,"data32");
         }
     }
+#if defined(XED_APX)
+    if (xed_decoded_inst_get_attribute(pi->p, XED_ATTRIBUTE_APX_NF))
+        xed_prefixes(pi,"{nf}");
+#endif   
     if (pi->emitted)
         xml_print_end(pi,"PREFIXES");
     if (pi->emitted)
@@ -360,6 +415,21 @@ xed_decoded_inst_dump_common(xed_print_info_t* pi)
     pi->emitted = 0;
 }
 
+/* Emits disassembly components that appear after the mnemonic and before the operands.
+ * (Current this is only the DFV) */
+static void
+xed_decoded_inst_dump_common_post_mne(xed_print_info_t* pi)
+{
+#if defined(XED_APX)
+    if (xed_decoded_inst_uses_rflags(pi->p) && xed_decoded_inst_has_default_flags_values(pi->p)) {
+        /* print Default Flags Values */
+        pi->blen = xed_strncat(pi->buf, " ",pi->blen);
+        pi->blen = xed_print_cvt(pi->p, pi->buf, pi->blen, XED_OPERAND_CONVERT_DFVSTR);
+    }
+#endif
+    (void)pi;
+}
+
 
 static const char* instruction_name_att(const xed_decoded_inst_t* p)
 
@@ -376,46 +446,6 @@ static const char* instruction_name_intel(const xed_decoded_inst_t* p)
 
 
 ///////////////////////////////////////////////////////////////////////////////
-static int xed_print_cvt(const xed_decoded_inst_t* p, 
-                         char* buf,
-                         int blen,
-                         xed_operand_convert_enum_t    cvt) {
-    // 32bit var is enough since the only operand wider than 32b disp/imm 
-    // and we are not decorating those
-    xed_uint_t opvalue;
-    xed_operand_enum_t index_operand = xed_convert_table[cvt].opnd;
-    xed3_get_generic_operand(p,index_operand,&opvalue);
-    if (opvalue < xed_convert_table[cvt].limit) {
-        const char* s = xed_convert_table[cvt].table_name[ opvalue ];
-        blen = xed_strncat(buf,s,blen);
-    }
-    else 
-        blen = xed_strncat(buf,"BADCVT",blen);
-    return blen;
-}
-
-static int xml_tag(char* buf, int blen, char const* tag, xed_uint_t value) {
-    char tbuf[XED_HEX_BUFLEN];
-
-    blen = xed_strncat(buf,"<",blen);
-    blen = xed_strncat(buf,tag,blen);
-    blen = xed_strncat(buf," bits=\"",blen); 
-
-    xed_sprintf_uint32(tbuf, value, XED_HEX_BUFLEN);
-    blen = xed_strncat(buf,tbuf,blen); 
-
-    blen = xed_strncat(buf,"\">",blen);
-    return blen;
-}
-
-static void xml_tag_pi(xed_print_info_t* pi,
-                      char const* tag,
-                      xed_uint_t value)
-{
-    pi->blen = xml_tag(pi->buf, pi->blen, tag, value);
-}
-
-
 static void xed_operand_spacer(xed_print_info_t* pi) {
     if (pi->emitted) {
         pi->blen = xed_strncat(pi->buf,", ",pi->blen);
@@ -1124,13 +1154,15 @@ xed_decoded_inst_dump_intel_format_internal(xed_print_info_t* pi)
     if (pi->format_options.xml_a)
         xed_pi_strcat(pi,"<INS>");
 
-    xed_decoded_inst_dump_common(pi);
+    xed_decoded_inst_dump_common_pre_mne(pi);
     
     instruction_name = instruction_name_intel(pi->p);
     if (pi->format_options.xml_a)
         xed_pi_strcat(pi,"<ICLASS>");
     pi->blen = xed_strncat_lower(pi->buf, instruction_name, pi->blen);
     xml_print_end(pi,"ICLASS");
+
+    xed_decoded_inst_dump_common_post_mne(pi);
     
     noperands = xed_inst_noperands(xi);
     // to avoid printing the space in the no-operands case, it is
@@ -1187,7 +1219,7 @@ xed_decoded_inst_dump_att_format_internal(
         return 0;
 
     setup_print_info(pi);
-    xed_decoded_inst_dump_common(pi);
+    xed_decoded_inst_dump_common_pre_mne(pi);
     
     instruction_name = instruction_name_att(pi->p);
     pi->blen = xed_strncat_lower(pi->buf, instruction_name, pi->blen);
@@ -1195,6 +1227,8 @@ xed_decoded_inst_dump_att_format_internal(
     if (suffix) {
         xed_pi_strcat(pi,suffix);
     }
+
+    xed_decoded_inst_dump_common_post_mne(pi);
     
     noperands = xed_inst_noperands(xi);    
     if (noperands)
